@@ -12,6 +12,9 @@ from gitlabform.gitlab.merge_requests import GitLabMergeRequests
 from gitlabform.gitlab.pipelines import GitLabPipelines
 from gitlabform.gitlab.project_badges import GitLabProjectBadges
 from gitlabform.gitlab.project_deploy_keys import GitLabProjectDeployKeys
+from gitlabform.gitlab.project_protected_environments import (
+    GitLabProjectProtectedEnvironments,
+)
 from gitlabform.gitlab.variables import GitLabVariables
 from gitlabform.gitlab.repositories import GitLabRepositories
 from gitlabform.gitlab.resource_groups import GitLabResourceGroups
@@ -64,5 +67,6 @@ class GitLab(
     GitLabProjectBadges,
     GitLabProjectDeployKeys,
     GitLabVariables,
+    GitLabProjectProtectedEnvironments,
 ):
     pass
