@@ -1,4 +1,6 @@
 from abc import ABC, abstractmethod
+from logging import debug
+from typing import Any, Callable, Union
 
 from cli_ui import debug as verbose
 
@@ -11,12 +13,18 @@ class AbstractProcessor(ABC):
     def __init__(self, configuration_name: str, gitlab: GitLab):
         self.configuration_name = configuration_name
         self.gitlab = gitlab
+        self.custom_diff_analyzers: dict[
+            str,
+            Callable[
+                [str, list[dict[str, Union[str, int]]], list[dict[str, int]]], bool
+            ],
+        ] = {}
 
     @configuration_to_safe_dict
     def process(
         self,
         project_or_project_and_group: str,
-        configuration: dict,
+        configuration,
         dry_run: bool,
         effective_configuration: EffectiveConfiguration,
     ):
@@ -67,8 +75,8 @@ class AbstractProcessor(ABC):
     def _print_diff(self, project_or_project_and_group: str, entity_config):
         verbose(f"Diffing for section '{self.configuration_name}' is not supported yet")
 
-    @staticmethod
     def _needs_update(
+        self,
         entity_in_gitlab: dict,
         entity_in_configuration: dict,
     ):
@@ -89,7 +97,47 @@ class AbstractProcessor(ABC):
             entity_in_gitlab.keys()
         )
         for key in keys_on_both_sides:
+            if key in self.custom_diff_analyzers:
+                return self.custom_diff_analyzers[key](
+                    key, entity_in_gitlab[key], entity_in_configuration[key]
+                )
+
             if entity_in_gitlab[key] != entity_in_configuration[key]:
+                debug(
+                    f"entity_in_gitlab[{key}] -> {entity_in_gitlab[key]} != entity_in_configuration[{key}] -> {entity_in_configuration[key]}"
+                )
                 return True
 
         return False
+
+    @staticmethod
+    def recursive_diff_analyzer(cfg_key: str, cfg_in_gitlab: list, local_cfg: list):
+        """
+        :return: True if the lists are NOT equal, False otherwise
+        """
+        if len(cfg_in_gitlab) != len(local_cfg):
+            return True
+
+        for index in range(len(cfg_in_gitlab)):
+            from_gitlab = {
+                k: v for k, v in cfg_in_gitlab[index].items() if v is not None
+            }
+            from_local_cfg = local_cfg[index]
+
+            keys_on_both_sides = set(from_gitlab.keys()) & set(from_local_cfg.keys())
+
+            for key in keys_on_both_sides:
+                if isinstance(from_gitlab[key], list) and isinstance(
+                    from_local_cfg[key], list
+                ):
+                    AbstractProcessor.recursive_diff_analyzer(
+                        key, from_gitlab[key], from_local_cfg[key]
+                    )
+
+                if from_gitlab[key] != from_local_cfg[key]:
+                    debug(
+                        f"* A <{key}> in [{cfg_key}] differs:\n GitLab :: {from_gitlab} != Local :: {from_local_cfg}"
+                    )
+                    return True
+
+        return False
